openwisp-ipam
=============

.. image:: https://github.com/openwisp/openwisp-ipam/actions/workflows/ci.yml/badge.svg?branch=master
    :target: https://github.com/openwisp/openwisp-ipam/actions/workflows/ci.yml?query=workflow%3AOpenWISP+Ipam+CI+Build%22
    :alt: CI Build status

.. image:: https://coveralls.io/repos/openwisp/openwisp-ipam/badge.svg
    :target: https://coveralls.io/r/openwisp/openwisp-ipam
    :alt: Coverage

.. image:: https://img.shields.io/pypi/v/openwisp-ipam
    :target: https://pypi.org/project/openwisp-ipam
    :alt: PyPI

.. image:: https://img.shields.io/librariesio/release/github/openwisp/openwisp-ipam
    :target: https://libraries.io/github/openwisp/openwisp-ipam#dependencies
    :alt: Dependency monitoring

.. image:: https://github.com/openwisp/openwisp-ipam/raw/docs/docs/subnet_demo.gif
    :alt: Feature Highlights

For a complete overview of features, refer to the `IPAM: Features
<https://openwisp.io/docs/dev/ipam/user/intro.html>`_ section of the
OpenWISP documentation.

Documentation
-------------

- `Usage documentation <https://openwisp.io/docs/dev/ipam/>`_
- `Developer documentation
  <https://openwisp.io/docs/dev/ipam/developer/>`_

Changelog
---------

See `Change log
<https://github.com/openwisp/openwisp-ipam/blob/master/CHANGES.rst>`__.

Contributing
------------

Please refer to the `OpenWISP contributing guidelines
<https://openwisp.io/docs/developer/contributing.html>`_.

Support
-------

See `OpenWISP Support Channels <https://openwisp.org/support.html>`_.

Changelog
---------

See `CHANGES
<https://github.com/openwisp/openwisp-ipam/blob/master/CHANGES.rst>`_.

License
-------

See `LICENSE
<https://github.com/openwisp/openwisp-ipam/blob/master/LICENSE>`_.
